@@ -20,9 +20,9 @@ pub type Square = shape_core::Square<f32>;
 pub type Rectangle = shape_core::Rectangle<f32>;
 /// A triangle without rotated.
 pub type Triangle = shape_core::Triangle<f32>;
-#[doc(hidden)]
+/// A polygon without rotated.
 pub type Polygon = shape_core::Polygon<f32>;
-#[doc(hidden)]
+/// A polyline without rotated.
 pub type Polyline = shape_core::Polyline<f32>;
-#[doc(hidden)]
+/// A path defined by a sequence of points.
 pub type RegularPolygon = shape_core::RegularPolygon<f32>;
